@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2009 Jiri (George) Lebl
+ * Copyright (C) 1997-2012 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
@@ -1993,7 +1993,7 @@ load_compiled_fp (const char *file, FILE *fp)
 
 	while ( ! break_on_next && fgets (buf, buf_size, fp) != NULL) {
 		char *p;
-		char *b2;
+		char *b2 = NULL;
 		GelToken *tok, *symbolic_tok = NULL;
 		int size, nargs, vararg, propagate_mod, no_mod_all_args;
 		int local_all, never_on_subst_list, built_subst_dict;
@@ -2589,7 +2589,7 @@ print_command_help (const char *cmd)
 
 	if (strcmp (cmd, "load") == 0) {
 		gel_output_full_string (gel_main_out,
-					_("Load a file into the interpretor"));
+					_("Load a file into the interpreter"));
 	} else if (strcmp (cmd, "plugin") == 0) {
 		gel_output_full_string (gel_main_out,
 					_("Load a plugin"));
@@ -2726,6 +2726,7 @@ gel_help_on (const char *text)
 				   NULL /* help_html */ };
 	GelEFunc *f;
 	int i;
+	gboolean documented_or_func_or_param = TRUE;
 
 	gel_output_push_nonotify (gel_main_out);
 
@@ -2762,10 +2763,18 @@ gel_help_on (const char *text)
 		return;
 	}
 
-	do_cyan ();
 
 	f = d_lookup_global (d_intern (text));
 
+	if (f == NULL &&
+	    help == &not_documented &&
+	    ! d_intern (text)->parameter) {
+		documented_or_func_or_param = FALSE;
+	}
+
+	if (documented_or_func_or_param)
+		do_cyan ();
+
 	if (d_intern (text)->parameter) {
 		gel_output_printf_full (gel_main_out, FALSE, "%s%s\n",
 					_("Parameter: "), text);
@@ -2773,7 +2782,8 @@ gel_help_on (const char *text)
 		   || (f->type == GEL_BUILTIN_FUNC &&
 		       f->named_args == NULL &&
 		       ! f->vararg)) {
-		gel_output_printf_full (gel_main_out, FALSE, "%s\n", text);
+		if (documented_or_func_or_param)
+			gel_output_printf_full (gel_main_out, FALSE, "%s\n", text);
 	} else {
 		GSList *li;
 		gel_output_printf_full (gel_main_out, FALSE, "%s (", text);
@@ -2789,7 +2799,8 @@ gel_help_on (const char *text)
 			gel_output_full_string (gel_main_out, "...");
 		gel_output_full_string (gel_main_out, ")\n");
 	}
-	do_green ();
+	if (documented_or_func_or_param)
+		do_green ();
 
 	if (help->aliases != NULL) {
 		GSList *li;
@@ -2803,7 +2814,7 @@ gel_help_on (const char *text)
 		g_string_free (gs, TRUE);
 	}
 
-	if (help->description != NULL) {
+	if (documented_or_func_or_param && help->description != NULL) {
 		gel_output_printf_full (gel_main_out, FALSE,
 					_("Description: %s\n"),
 					_(help->description));
